==> openGion7.0.2.3_dev.zip: uap/webapps/ge/db/DERBY/sql/install/01_TABLE/GEA09S.sql <==
/****************************************************************************/
/* GEA09 ( ﾕｰｻﾞｰｱｸｾｽ画面管理ﾃｰﾌﾞﾙ )                                         */
/*                                                                          */
/* Created : 2018/09/28 16:03:46                                            */
/****************************************************************************/

CREATE TABLE GEA09 (
   SYSTEM_ID    VARCHAR (   10 )                    NOT NULL                                                                                                            /*  10 ｼｽﾃﾑID       */
 , USERID       VARCHAR (   10 )                    NOT NULL                                                                                                            /*  20 ﾕｰｻﾞｰID      */
 , GUIKEY       VARCHAR (   30 )                    NOT NULL                                                                                                            /*  30 画面ID       */
 , SEQNO        INTEGER                 DEFAULT 0   NOT NULL                                                                                                            /*  40 表示順       */
 , NAME_JA      VARCHAR (  200 )                                                                                                                                        /*  50 名称         */
 , LAST_ACCESS  VARCHAR (   14 )                                                                                                                                        /*  60 最終ｱｸｾｽ時間 */
 , FGFAVORITE   VARCHAR (    1 )                                                                                                                                        /*  70 お気に入り   */
 , CLASSIFY     VARCHAR (  120 )                                                                                                                                        /*  80 分類         */
 , NEXTGUI      VARCHAR ( 1000 )                                                                                                                                        /*  90 次画面ﾘｽﾄ    */
 , UNIQ         BIGINT                              NOT NULL     generated always as identity (start with 1, increment by 1),constraint GEA09 primary key(UNIQ)         /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR (    1 )        DEFAULT '1' NOT NULL                                                                                                            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR (   14 )                                                                                                                                        /* 820 登録日時     */
 , PGSET        VARCHAR (   10 )                                                                                                                                        /* 830 作成PG       */
 , PGPSET       VARCHAR (   10 )                                                                                                                                        /* 840 作成親PG     */
 , USRSET       VARCHAR (   10 )                                                                                                                                        /* 850 作成者       */
 , DYUPD        VARCHAR (   14 )                                                                                                                                        /* 860 更新日時     */
 , PGUPD        VARCHAR (   10 )                                                                                                                                        /* 870 更新PG       */
 , PGPUPD       VARCHAR (   10 )                                                                                                                                        /* 880 更新親PG     */
 , USRUPD       VARCHAR (   10 )                                                                                                                                        /* 890 更新者       */
);

==> openGion7.3.0.1_dev.zip: uap/webapps/ge/db/DERBY/sql/install/01_TABLE/GEA09S.sql <==
/****************************************************************************/
/* GEA09 ( ｱｸｾｽ管理ﾃｰﾌﾞﾙ )                                                  */
/*                                                                          */
/* Created : 2020/12/16 08:14:26                                            */
/****************************************************************************/

CREATE TABLE GEA09 (
   SYSTEM_ID    VARCHAR (   10 )                    NOT NULL                                                                                                            /*  10 ｼｽﾃﾑID       */
 , USERID       VARCHAR (   10 )                    NOT NULL                                                                                                            /*  20 ﾕｰｻﾞｰID      */
 , GUIKEY       VARCHAR (   30 )                    NOT NULL                                                                                                            /*  30 画面ID       */
 , SEQNO        INTEGER                 DEFAULT 0   NOT NULL                                                                                                            /*  40 表示順       */
 , NAME_JA      VARCHAR (  200 )                                                                                                                                        /*  50 名称         */
 , LAST_ACCESS  VARCHAR (   14 )                                                                                                                                        /*  60 最終ｱｸｾｽ時間 */
 , FGFAVORITE   VARCHAR (    1 )                                                                                                                                        /*  70 お気に入り   */
 , CLASSIFY     VARCHAR (  120 )                                                                                                                                        /*  80 分類         */
 , NEXTGUI      VARCHAR ( 1000 )                                                                                                                                        /*  90 次画面ﾘｽﾄ    */
 , UNIQ         BIGINT                              NOT NULL     generated always as identity (start with 1, increment by 1),constraint GEA09 primary key(UNIQ)         /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR (    1 )        DEFAULT '1' NOT NULL                                                                                                            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR (   14 )                                                                                                                                        /* 820 作成日時     */
 , PGSET        VARCHAR (   10 )                                                                                                                                        /* 830 作成PG       */
 , PGPSET       VARCHAR (   10 )                                                                                                                                        /* 840 作成親PG     */
 , USRSET       VARCHAR (   10 )                                                                                                                                        /* 850 作成者       */
 , DYUPD        VARCHAR (   14 )                                                                                                                                        /* 860 更新日時     */
 , PGUPD        VARCHAR (   10 )                                                                                                                                        /* 870 更新PG       */
 , PGPUPD       VARCHAR (   10 )                                                                                                                                        /* 880 更新親PG     */
 , USRUPD       VARCHAR (   10 )                                                                                                                                        /* 890 更新者       */
);
